@@ -1,10 +1,9 @@
 use Object::Pad ':experimental(init_expr)';
 # ABSTRACT: The status of an OpenTelemetry span
 
-package
-    OpenTelemetry::Trace::Span::Status;
+package OpenTelemetry::Trace::Span::Status;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 use Log::Any;
 my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
